Payload class

Annotations
  • @JsonSerializable.new()

Constructors

Payload({String? description, String? name, List<int>? users, bool? isPersonal})
Payload.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isPersonal → bool?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
users → List<int>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited