DirectMessage class

Annotations
  • @JsonSerializable.new()

Constructors

DirectMessage({int? fromUser, int? group, List? mentions, String? deltaContent, String? htmlContent, String? textContent, dynamic replyTo, bool? isBase64Encoded})
DirectMessage.fromJson(Map<String, dynamic> json)
factory

Properties

deltaContent → String?
final
fromUser → int?
final
group → int?
final
hashCode → int
The hash code for this object.
no setterinherited
htmlContent → String?
final
isBase64Encoded → bool?
final
mentions → List?
final
replyTo → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textContent → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited