Payload class

Annotations
  • @JsonSerializable.new()

Constructors

Payload({int? messageId, int? fileId})
Payload.fromJson(Map<String, dynamic> json)
factory

Properties

fileId → int?
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited